package kr.co.jinwoosi.clfd.framework.security.service;

import java.util.List;

import kr.co.jinwoosi.clfd.framework.base.service.BaseService;
import kr.co.jinwoosi.clfd.framework.security.model.User;
import kr.co.jinwoosi.clfd.framework.security.model.UserSearch;

public interface UserService extends BaseService<User, UserSearch>  {
	User login (User user);
	void findPw(UserSearch userSearch);
	int checkIdDuplicate(UserSearch userSearch);
	void updateUserLoginFail(User user);
	void updateInitUserLoginFailCnt(User user);
	int userPwdCheck(UserSearch userSearch);
	void updatePwd(User user);
	int userTotalOutCount();
	int thisWeekInUserCount();
	int thisWeekOutUser();
	List<User> thisWeekInUser();
}
